#ifndef _RENDER_TARGET_APP_H
#define _RENDER_TARGET_APP_H
/*====================================================================================
Class Name  : ARApp
Authors	    : Grant Clark, Ewan Duncan
Description : Main class of the program.  Manages the program states and renders 
			  all sprites and meshes.  Adapted by Ewan Duncan from Grant Clark's 
			  ARApp class.  
====================================================================================*/

/*------------------------------------------------------------------------------------
INCLUDES
------------------------------------------------------------------------------------*/
#include <system/application.h>
#include <graphics/vita/texture_vita.h>
#include <maths/matrix44.h>

#include "state_manager.h"

/*------------------------------------------------------------------------------------
FORWARD DECLARATIONS
------------------------------------------------------------------------------------*/
namespace abfw
{
	class Platform;
	class SpriteRenderer;
	class Font;
	class Renderer3D;
	class SonyControllerInputManager;
}

/*------------------------------------------------------------------------------------
AR APP CLASS
------------------------------------------------------------------------------------*/
class ARApp : public abfw::Application
{
 public:
	ARApp(abfw::Platform& platform);
	void Init();
	void CleanUp();
	bool Update(float frame_time);
	void Render();

 private:
	void InitFont();
	void CleanUpFont();
	void DrawHUD();
	void RenderOverlay();

	abfw::SonyControllerInputManager* input_manager_;
	abfw::SpriteRenderer* sprite_renderer_;
	abfw::Font* font_;
	float fps_;
	class abfw::Renderer3D* renderer_3d_;
	abfw::Matrix44 fov_projection_matrix_;
	abfw::Matrix44 orthographic_projection_;
	float vertical_image_scale_factor_;
	abfw::Sprite camera_image_sprite_;
	abfw::TextureVita texture_map_;
	StateManager state_manager_;
};

/*------------------------------------------------------------------------------------
END OF FILE
------------------------------------------------------------------------------------*/
#endif
