#ifndef GAME_OBJECT_H
#define GAME_OBJECT_H
/*====================================================================================
Class Name  : GameObject
Authors	    : Ewan Duncan
Description : Class that represents a 3D object in the game that gets updated and 
			  rendered.  
====================================================================================*/

/*------------------------------------------------------------------------------------
INCLUDES
------------------------------------------------------------------------------------*/
#include <system/platform.h>
#include <maths/vector3.h>
#include <maths/aabb.h>
#include <graphics/mesh_instance.h>
#include <graphics/model.h>
#include <iostream>

/*------------------------------------------------------------------------------------
FORWARD DECLARATIONS
------------------------------------------------------------------------------------*/
namespace abfw
{
	class Platform;
	class Renderer3D;
	class SonyController;
}

/*------------------------------------------------------------------------------------
ENUMS
------------------------------------------------------------------------------------*/
enum ObjectType {kLevelGeometry, kStart, kGoal};

/*------------------------------------------------------------------------------------
GAME OBJECT CLASS
------------------------------------------------------------------------------------*/
class GameObject : public abfw::MeshInstance
{
 public:
	 GameObject();
	 virtual ~GameObject();

	 virtual void Update(float frame_time, const abfw::SonyController* controller) {};
	 void Render(abfw::Renderer3D* renderer_3d);
	 abfw::Mesh* CreateModelMesh(const char* filename, const abfw::Platform& platform, const abfw::Aabb aabb);
	 abfw::Mesh* CreateCubeMesh(const char* texture_filename, const abfw::Platform& platform);
	 abfw::Texture* LoadTextureFromPNG(const char* filename, const abfw::Platform& platform);
	 void MultiplyByMarkerTransform(int marker_index);
	 abfw::Matrix44 GetLocalMarkerTransform(int reference_marker_index, int marker_index);
	 void SetPosition(const float x_position, const float y_position, const float z_position);
	 void SetPosition(const abfw::Vector3 position);
	 void SetXPosition(const float x_position);
	 void SetYPosition(const float y_position);
	 void SetZPosition(const float z_position);
	 abfw::Vector3 GetPosition();
	 void MoveDeltaX(const float x_distance);
	 void MoveDeltaY(const float y_distance);
	 void MoveDeltaZ(const float z_distance);
	 void SetXRotation(const float x_rotation);
	 void SetYRotation(const float y_rotation);
	 void SetZRotation(const float z_rotation);
	 void Scale(const float x_scale, const float y_scale, const float z_scale);
	 bool AABBCollision(GameObject& other_object);

	 inline const abfw::Matrix44 get_local_transform() const { return local_transform_; }
	 inline const ObjectType get_object_type() const { return object_type_; }
	 inline void set_object_type(const ObjectType object_type) { object_type_ = object_type; }

 private:
	 abfw::Model model_;
	 abfw::Matrix44 local_transform_;
	 ObjectType object_type_;
};

/*------------------------------------------------------------------------------------
END OF FILE
------------------------------------------------------------------------------------*/
#endif
