/*====================================================================================
Class Name  : LevelCompleteState
Authors	    : Ewan Duncan
Description : Used to show when a player has reached the end of a level and take the 
			  user back to the level editor.
====================================================================================*/

/*------------------------------------------------------------------------------------
INCLUDES
------------------------------------------------------------------------------------*/
#include "level_complete_state.h"

/*------------------------------------------------------------------------------------
MEMBER FUNCTIONS
------------------------------------------------------------------------------------*/

/*====================================================================================
Name    : Init
Purpose : Initialises a sprite that states the player has reached the end of a level 
		  and can press start to go back to the level editor.
====================================================================================*/
void LevelCompleteState::Init()
{
	const float sprite_width = 1.5f;
	const float sprite_height = 1.f;

	back_to_level_editor_.set_width(sprite_width);
	back_to_level_editor_.set_height(sprite_height);
	back_to_level_editor_.set_position(0.f, 0.f, 1.f);
	GameObject texture_loader;
	back_to_level_editor_.set_texture(texture_loader.LoadTextureFromPNG("levelcomplete.png", *platform_));
}

/*====================================================================================
Name    : CleanUp
Purpose : Performs any necessary memory cleanup.
====================================================================================*/
void LevelCompleteState::CleanUp()
{
}

/*====================================================================================
Name    : Update
Purpose : Handles the main loop for this state.
====================================================================================*/
void LevelCompleteState::Update(float frame_time, const abfw::SonyController* controller, StateManager* state_manager)
{
	// when the start button is pressed, go back to the level editor
	if (controller->buttons_pressed() & ABFW_SONY_CTRL_START)
	{
		state_manager->PopState();
	}
}

/*====================================================================================
Name    : Render
Purpose : Renders the return to level editor sprite.  
====================================================================================*/
void LevelCompleteState::Render(abfw::SpriteRenderer* sprite_renderer, abfw::Renderer3D* renderer_3d)
{
	sprite_renderer->DrawSprite(back_to_level_editor_);
}

/*------------------------------------------------------------------------------------
END OF FILE
------------------------------------------------------------------------------------*/
