#ifndef LEVEL_EDITOR_H
#define LEVEL_EDITOR_H
/*====================================================================================
Class Name  : LevelEditor
Authors	    : Ewan Duncan
Description : A movable cursor that can create and delete cubes that make up the 
			  geometry of a playable level.  
====================================================================================*/

/*------------------------------------------------------------------------------------
INCLUDES
------------------------------------------------------------------------------------*/
#include "game_object.h"

/*------------------------------------------------------------------------------------
CONSTANTS
------------------------------------------------------------------------------------*/
const float kBlockSize = 0.025f;

/*------------------------------------------------------------------------------------
LEVEL EDITOR CLASS
------------------------------------------------------------------------------------*/
class LevelEditor : public GameObject
{
 public:
	 void Init(abfw::Platform* platform, std::vector<GameObject>& level_blocks);
	 void Update(float frame_time, const abfw::SonyController* controller, std::vector<GameObject>& level_blocks);
	 void CreateBlock(float x_position, float y_position, float z_position, std::vector<GameObject>& level_blocks, ObjectType object_type);
	 
 private:
	 void MoveCursor(float frame_time, const abfw::SonyController* controller);
	 void EditLevel(const abfw::SonyController* controller, std::vector<GameObject>& level_blocks);
	 abfw::Platform* platform_;
	 abfw::Mesh* start_block_;
	 abfw::Mesh* goal_block_;
	 abfw::Mesh* geometry_block_;
};

/*------------------------------------------------------------------------------------
END OF FILE
------------------------------------------------------------------------------------*/
#endif
