/*====================================================================================
Class Name  : MarkerLostState
Authors	    : Ewan Duncan
Description : Used to pause the previous program state until the ar marker is found.
====================================================================================*/

/*------------------------------------------------------------------------------------
INCLUDES
------------------------------------------------------------------------------------*/
#include "marker_lost_state.h"

/*------------------------------------------------------------------------------------
MEMBER FUNCTIONS
------------------------------------------------------------------------------------*/

/*====================================================================================
Name    : Init
Purpose : Initialises a sprite that states the marker isn't found.
====================================================================================*/
void MarkerLostState::Init()
{
	const float sprite_size = 1.f;

	marker_not_found_.set_width(sprite_size);
	marker_not_found_.set_height(sprite_size);
	marker_not_found_.set_position(0.f, 0.f, 1.f);
	GameObject texture_loader;
	marker_not_found_.set_texture(texture_loader.LoadTextureFromPNG("markerlost.png", *platform_));
}

/*====================================================================================
Name    : CleanUp
Purpose : Performs any necessary memory cleanup.
====================================================================================*/
void MarkerLostState::CleanUp()
{
}

/*====================================================================================
Name    : Update
Purpose : Handles the main loop for this state.
====================================================================================*/
void MarkerLostState::Update(float frame_time, const abfw::SonyController* controller, StateManager* state_manager)
{
	// when the ar marker is found, revert to the previous program state
	if (sampleIsMarkerFound(marker_index_) == true && sampleIsMarkerFound(player_marker_index_) == true)
	{
		state_manager->PopState();
	}
}

/*====================================================================================
Name    : Render
Purpose : Renders the marker not found sprite.
====================================================================================*/
void MarkerLostState::Render(abfw::SpriteRenderer* sprite_renderer, abfw::Renderer3D* renderer_3d)
{
	sprite_renderer->DrawSprite(marker_not_found_);
}

/*------------------------------------------------------------------------------------
END OF FILE
------------------------------------------------------------------------------------*/
