/*====================================================================================
Class Name  : MarkerSelectState
Authors	    : Ewan Duncan
Description : Used to select an ar marker to be used as the reference transform for
			  the other program states.
====================================================================================*/

/*------------------------------------------------------------------------------------
INCLUDES
------------------------------------------------------------------------------------*/
#include "marker_select_state.h"

#include "level_edit_state.h"

/*------------------------------------------------------------------------------------
MEMBER FUNCTIONS
------------------------------------------------------------------------------------*/

/*====================================================================================
Name    : Init
Purpose : Initialises sprites used to help the user find an marker.
====================================================================================*/
void MarkerSelectState::Init()
{
	const float sprite_width = 1.f;
	const float sprite_height = 0.35f;
	const float sprite_offset = 0.75f;

	// game object used to load textures for the sprites
	GameObject texture_loader;

	// this sprite tells the user to place a marker in front of the camera
	select_marker_.set_width(sprite_width);
	select_marker_.set_height(sprite_height);
	select_marker_.set_position(0.f, -sprite_offset, 1.f);
	select_marker_.set_texture(texture_loader.LoadTextureFromPNG("selectmarker.png", *platform_));

	// this sprite tells the user to press start to select a marker
	press_start_.set_width(sprite_width);
	press_start_.set_height(sprite_height);
	press_start_.set_position(0.f, sprite_offset, 1.f);
	press_start_.set_texture(texture_loader.LoadTextureFromPNG("pressstart.png", *platform_));
}

/*====================================================================================
Name    : CleanUp
Purpose : Performs any necessary memory cleanup.
====================================================================================*/
void MarkerSelectState::CleanUp()
{
}

/*====================================================================================
Name    : Update
Purpose : Handles the main loop for this state.
====================================================================================*/
void MarkerSelectState::Update(float frame_time, const abfw::SonyController* controller, StateManager* state_manager)
{
	// boolean for when a marker is found
	// set this to be true unless a marker isn't found
	marker_found_ = true;

	// create a new level edit state
	LevelEditState* level_edit_state;
	level_edit_state = new LevelEditState(platform_);
	
	// when a marker is found, set the marker index on the level edit state
	if (sampleIsMarkerFound(0) == true)
	{
		level_edit_state->set_marker_index(0);
	}
	else if (sampleIsMarkerFound(1) == true)
	{
		level_edit_state->set_marker_index(1);
	}
	else if (sampleIsMarkerFound(2) == true)
	{
		level_edit_state->set_marker_index(2);
	}
	else if (sampleIsMarkerFound(3) == true)
	{
		level_edit_state->set_marker_index(3);
	}
	else if (sampleIsMarkerFound(4) == true)
	{
		level_edit_state->set_marker_index(4);
	}
	else
	{
		// marker wasn't found
		marker_found_ = false;
		
		// delete the level edit state
		delete level_edit_state;
		level_edit_state = NULL;
	}

	// if a marker is found and the user presses start, change to the level edit state
	if (marker_found_ == true)
	{
		if (controller->buttons_pressed() & ABFW_SONY_CTRL_START)
		{
			state_manager->ChangeState(level_edit_state);
		}
	}
}

/*====================================================================================
Name    : Render
Purpose : Renders the sprites.  
====================================================================================*/
void MarkerSelectState::Render(abfw::SpriteRenderer* sprite_renderer, abfw::Renderer3D* renderer_3d)
{
	sprite_renderer->DrawSprite(select_marker_);

	// only render this sprite if a marker was found in the update
	if (marker_found_ == true)
	{
		sprite_renderer->DrawSprite(press_start_);
	}
}

/*------------------------------------------------------------------------------------
END OF FILE
------------------------------------------------------------------------------------*/
