#ifndef PLAYER_H
#define PLAYER_H
/*====================================================================================
Class Name  : Player
Authors	    : Ewan Duncan
Description : Object that represents the player in the game.  Can be moved with an 
			  ar marker and jump with button input.  
====================================================================================*/

/*------------------------------------------------------------------------------------
INCLUDES
------------------------------------------------------------------------------------*/
#include "game_object.h"

/*------------------------------------------------------------------------------------
CONSTANTS
------------------------------------------------------------------------------------*/
const float kVerticalAcceleration = 0.02f;
const float kMaxVerticalVelocity = 0.5f;
const float kInitialVerticalVelocity = 0.3f;

/*------------------------------------------------------------------------------------
PLAYER CLASS
------------------------------------------------------------------------------------*/
class Player : public GameObject
{
 public:
	void Init(abfw::Platform* platform, std::vector<GameObject>& level_blocks, const int level_marker_index);
	void Update(float frame_time, const abfw::SonyController* controller, std::vector<GameObject>& level_blocks);
	abfw::Vector3 FindMarkerPosition();

	inline const bool get_goal_reached() const { return goal_reached_; }
	inline const int get_player_marker_index() const { return player_marker_index_; }
	inline void set_previous_marker_position(const abfw::Vector3 previous_marker_position) { previous_marker_position_ = previous_marker_position; }

 private:
	 void MoveWithMarker(float frame_time);
	 void Jump(float frame_time, const abfw::SonyController* controller);
	 void PlatformCollisionDetection(std::vector<GameObject>& level_blocks);
	 void LevelCollisionDetection(abfw::Vector3 temp_position, std::vector<GameObject>& level_blocks);
	 bool goal_reached_;
	 bool on_platform_;
	 GameObject feet_;
	 float vertical_velocity_;
	 abfw::Vector3 previous_marker_position_;
	 int level_marker_index_;
	 int player_marker_index_;
};

/*------------------------------------------------------------------------------------
END OF FILE
------------------------------------------------------------------------------------*/
#endif
