#ifndef STATE_H
#define STATE_H
/*====================================================================================
Class Name  : State
Authors	    : Ewan Duncan
Description : Class used as a base state that other program states inherit from.  
====================================================================================*/

/*------------------------------------------------------------------------------------
INCLUDES
------------------------------------------------------------------------------------*/
#include <graphics/sprite_renderer.h>
#include <graphics/sprite.h>
#include <graphics/renderer_3d.h>
#include <input/sony_controller_input_manager.h>
#include <sony_sample_framework.h>

#include "game_object.h"

/*------------------------------------------------------------------------------------
FORWARD DECLARATIONS
------------------------------------------------------------------------------------*/
class StateManager;

namespace abfw
{
	class Platform;
}

/*------------------------------------------------------------------------------------
STATE CLASS
------------------------------------------------------------------------------------*/
class State
{
 public:
	 State(abfw::Platform* platform) { platform_ = platform; }
	 virtual ~State() {}

	 virtual void Init() = 0;
	 virtual void CleanUp() = 0;
	 virtual void Update(float frame_time, const abfw::SonyController* controller, StateManager* state_manager) = 0;
	 virtual void Render(abfw::SpriteRenderer* sprite_renderer, abfw::Renderer3D* renderer_3d) = 0;

	 inline void set_marker_index(const int marker_index) { marker_index_ = marker_index; }

 protected:
	 abfw::Platform* platform_;
	 int marker_index_;
};

/*------------------------------------------------------------------------------------
END OF FILE
------------------------------------------------------------------------------------*/
#endif
