/*====================================================================================
Class Name  : StateManager
Authors	    : Ewan Duncan
Description : Stores all the states of the application and provides functions to
			  switch between them.
====================================================================================*/

/*------------------------------------------------------------------------------------
INCLUDES
------------------------------------------------------------------------------------*/
#include "state_manager.h"

/*------------------------------------------------------------------------------------
MEMBER FUNCTIONS
------------------------------------------------------------------------------------*/

/*====================================================================================
Name    : ChangeState
Purpose : Deletes the current state and switches to a new one.  
====================================================================================*/
void StateManager::ChangeState(State* state)
{
	// clean up and delete the current state
	if (states_.empty() == false)
	{
		states_.back()->CleanUp();
		states_.pop_back();
	}

	// store and initialise the new state
	states_.push_back(state);
	states_.back()->Init();
}

/*====================================================================================
Name    : PushState
Purpose : Keeps the current state and switches to a new one.  
====================================================================================*/
void StateManager::PushState(State* state)
{
	// store and initialise the new state
	states_.push_back(state);
	states_.back()->Init();
}

/*====================================================================================
Name    : PopState
Purpose : Deletes the current state and switches to the previous one.
====================================================================================*/
void StateManager::PopState()
{
	// clean up and delete the current state
	if (states_.empty() == false)
	{
		states_.back()->CleanUp();
		states_.pop_back();
	}
}

/*====================================================================================
Name    : Clear
Purpose : Deletes all of the states.  
====================================================================================*/
void StateManager::Clear()
{
	// clean up and delete all states in the vector
	while (states_.empty() == false)
	{
		states_.back()->CleanUp();
		states_.pop_back();
	}
}

/*------------------------------------------------------------------------------------
END OF FILE
------------------------------------------------------------------------------------*/
